import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/VAbhiram99/f5bdf2694d0f350533eb42c27c0fc623/raw/8a9898286b4f1b243f21c426b3abc1b7e2d6f6c6/ICE-6'
].join('');
const parseRow = (d) => {
  d.bill_length_mm = +d.bill_length_mm;
  d.bill_depth_mm = +d.bill_depth_mm;
  d.flipper_length_mm = +d.flipper_length_mm;
  d.body_mass_g = +d.body_mass_g;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.body_mass_g)
    .yValue((d) => d.bill_length_mm)
    .margin({
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    })
    .radius(3);

  svg.call(plot);

  const columns = [
    'body_mass_g',
    'bill_depth_mm',
    'flipper_length_mm',
    'bill_length_mm',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();